==> haskell-iproute-1.7.15-83.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 iproute
version:              1.7.15
visibility:           public
id:                   iproute-1.7.15-8MQv32arzXu8ybbx4AUApr
key:                  iproute-1.7.15-8MQv32arzXu8ybbx4AUApr
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  2fcf76a33d9670241eaafe323162dc2f
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-9.6.6/site-local/iproute-1.7.15
library-dirs:         /usr/lib/ghc-9.6.6/site-local/iproute-1.7.15
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/iproute-1.7.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-iproute
hs-libraries:         HSiproute-1.7.15-8MQv32arzXu8ybbx4AUApr
depends:
    appar-0.1.8-35VNf41Gyn3ISAkAVOl5KW base-4.18.2.1
    byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2 bytestring-0.11.5.3
    containers-0.6.7 network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iproute-1.7.15-84-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 iproute
version:              1.7.15
visibility:           public
id:                   iproute-1.7.15-G8PIBt0bMmIHonL1qb456T
key:                  iproute-1.7.15-G8PIBt0bMmIHonL1qb456T
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  f48e2d43726d7261317edb5d3c309c99
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-9.6.6/site-local/iproute-1.7.15
library-dirs:         /usr/lib/ghc-9.6.6/site-local/iproute-1.7.15
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/iproute-1.7.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-iproute
hs-libraries:         HSiproute-1.7.15-G8PIBt0bMmIHonL1qb456T
depends:
    appar-0.1.8-35VNf41Gyn3ISAkAVOl5KW base-4.18.2.1
    byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2 bytestring-0.11.5.3
    containers-0.6.7 network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
